@@ -4,7 +4,7 @@ use warnings;
 use Time::HiRes qw/time/;
 use Test2::Harness::Util::UUID qw/gen_uuid/;
 
-our $VERSION = '0.000131';
+our $VERSION = '0.000132';
 
 use Test2::Harness::UI::Util::HashBase qw{
     <config
@@ -135,6 +135,13 @@ sub sweep_run {
 
     if ($params{runs}) {
         $run->reportings->delete;
+
+        my $batches = $run->resource_batches;
+        while (my $batch = $batches->next) {
+            $batch->resources->delete;
+            $batch->delete;
+        }
+
         $run->sweeps->delete;
         $run->delete;
     }
