@@ -371,13 +371,23 @@ CREATE INDEX reporting_c    ON reporting(project_id, test_file_id, subtest);
 CREATE INDEX reporting_d    ON reporting(project_id, test_file_id, subtest, user_id);
 CREATE INDEX reporting_e    ON reporting(project_id, test_file_id, subtest, user_id, run_ord);
 
+CREATE TABLE resource_batch (
+    resource_batch_id   CHAR(36)        NOT NULL PRIMARY KEY,
+    run_id              CHAR(36)        NOT NULL,
+    host_id             CHAR(36)        NOT NULL,
+    stamp               TIMESTAMP(4)    NOT NULL,
+
+    FOREIGN KEY (run_id)  REFERENCES runs(run_id),
+    FOREIGN KEY (host_id) REFERENCES hosts(host_id)
+) ROW_FORMAT=COMPRESSED;
+
 CREATE TABLE resources (
-    resource_id     CHAR(36)        NOT NULL PRIMARY KEY,
-    run_id          CHAR(36)        DEFAULT NULL,
+    resource_id         CHAR(36)        NOT NULL PRIMARY KEY,
+    resource_batch_id   CHAR(36)        NOT NULL,
+    batch_ord           INT             NOT NULL,
+    module              VARCHAR(512)    NOT NULL,
+    data                LONGTEXT        NOT NULL,
 
-    module          VARCHAR(512)    NOT NULL,
-    stamp           TIMESTAMP(4)    NOT NULL,
-    data            LONGTEXT        NOT NULL,
-
-    FOREIGN KEY (run_id)            REFERENCES runs(run_id)
-);
+    FOREIGN KEY (resource_batch_id) REFERENCES resource_batch(resource_batch_id),
+    UNIQUE(resource_batch_id, batch_ord)
+) ROW_FORMAT=COMPRESSED;
